rm(list = ls())
library(xrnet)
library(readxl)
library(glmnet)
library(ggplot2)
library(dplyr)
library(xtable)

#- Source important files
simSheet <- read_xlsx("simulationList.xlsx", sheet = 1)

# Make sure to comment and un-comment the correct model you are interested in.
#- Section 3.2 (Low Dimensional)
# idx = 1: n = 400, p = 50
# idx = 2: n = 800, p = 50
# idx = 3: n = 400, p = 200
# idx = 4: n = 800, p = 200
# idx = 5: Model 2
# idx = 7: Model 3
# idx = 8: Model 4

# OLS_ar_: idx = 1 - 4 (Table 2); idx = 5, 7, 8 (Table 3)
# OLS_cs_: idx = 1, 3 (Table S4)
# OLS_ind_: idx =  1, 3 (Table S4)

idx <- 2
load(file = paste0("results/results_s2_OLS_ar_", idx, ".RData"))
#load(file = paste0("results/results_s2_OLS_cs_", idx, ".RData"))
#load(file = paste0("results/results_s2_OLS_ind_", idx, ".RData"))

#- Section 3.2 (High Dimensional)
# idx = 1: n = 400, p = 2000; model 1
# idx = 2: n = 400, p = 2000; model 2
# OLS_HD_ar_: idx = 1 - 2 (Table 4)

#load(file = paste0("results/results_s2_OLS_HD_ind_", idx, ".RData"))
#load(file = paste0("results/results_s2_OLS_HD_ar_", idx, ".RData"))

#- Section 3.4:
# idx = 1, 5 (Table 5)
#load(file = paste0("results/results_s4_logistic_", idx, ".RData"))


beta0
B <- length(out)

source(paste0("sourceFiles/evaluationMeasures.R"))

# Store results in these matrices
bias_matrix <- matrix(NA, nrow = B, ncol = 23) # Calculate bias
mse_matrix  <- matrix(NA, nrow = B, ncol = 23) # Calculate prediction measure (PMSE or AUC)
fp_matrix   <- matrix(NA, nrow = B, ncol = 23) # Calculate # of FP
fn_matrix   <- matrix(NA, nrow = B, ncol = 23) # Calculate # of FN
beta_res    <- list()
opt_quant   <- matrix(NA, nrow = B, ncol = 1) # Calculate optimal tau
mean_y      <- numeric() # Calculate mean value of outcome (useful for binary outcome)

#- Get simulation results
for(b in 1:B) {
  bias_matrix[b, ] <- apply(out[[b]]$betas, 1, function(x) sqrt(sum((x - beta0)^2)))
  beta_res[[b]]    <- apply(out[[b]]$betas, 1, function(x) getBetaCounts(x, beta0))
  fn_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, beta0))[1, ]
  fp_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, beta0))[2, ]
  mse_matrix[b, ]  <- out[[b]]$mse
  opt_quant[b, ]   <- out[[b]]$opt 
  mean_y[b]        <- out[[b]]$meanY
}

beta_matrix <- matrix(NA, nrow = 23, ncol = 5)
for(i in 1:5) {
  tmp <- matrix(NA, nrow = B, ncol = 23)
  for(b in 1:B) {
    tmp[b, ] <- beta_res[[b]][i, ]
  }
  beta_matrix[, i] <- apply(tmp, 2,  mean)
}
rm(i, b)


#####- Output results
res_table <- cbind(apply(bias_matrix, 2, mean),
                   apply(fp_matrix, 2, mean),
                   apply(fn_matrix, 2, mean),
                   beta_matrix,
                   apply(mse_matrix, 2, mean))

res_table <- res_table[c(1, 2, 3, 4), ]; 
colnames(res_table) <- c("MSB", "FP", "FN", paste0("beta_", which(beta0!=0)), "PMSE")
rownames(res_table) <- c("Oracle", "LASSO", "nLASSO", "asymLASSO")
xtable(res_table)

apply(opt_quant, 2, mean)
