rm(list = ls())
library(xrnet)
library(readxl)
library(glmnet)
library(ggplot2)
library(dplyr)
library(gridExtra)
library(xtable)

#- Source important files
simSheet <- read_xlsx("simulationList.xlsx", sheet = 3)

# Make sure to comment and un-comment the correct model you are interested in.
# idx = 2: n = 400, p = 50, rho = 0 (i.e., independent covariates)
# idx = 3: n = 400, p = 50, rho = 0.5
# idx = 4: n = 400, p = 50, rho = 0.8

# s4_ar_: idx = 2 (Figure 3); idx = 3 (Figure S1)
# s4_cs_: idx = 4 (Figure S2)

idx <- 3
load(file = paste0("results/results_s4_ar_", idx, ".RData"))
#load(file = paste0("results/results_s4_cs_", idx, ".RData"))


simSheet
B <- length(out)

source(paste0("sourceFiles/evaluationMeasures.R"))

# Store results in these matrices
bias_matrix <- matrix(NA, nrow = B, ncol = 6)
mse_matrix  <- matrix(NA, nrow = B, ncol = 6)
r2_matrix   <- matrix(NA, nrow = B, ncol = 6)
fp_matrix   <- matrix(NA, nrow = B, ncol = 6)
fn_matrix   <- matrix(NA, nrow = B, ncol = 6)
sm_matrix   <- matrix(NA, nrow = B, ncol = 6)
beta_res    <- list()
opt_quant   <- matrix(NA, nrow = B, ncol = 2)
#- Get simulation results
for(b in 1:B) {
  bias_matrix[b, ] <- apply(out[[b]]$betas, 1, function(x) sum((x - beta0)^2))
  beta_res[[b]]    <- apply(out[[b]]$betas, 1, function(x) getBetaCounts(x, beta0))
  fn_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, beta0))[1, ]
  fp_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, beta0))[2, ]
  sm_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getSimilarityMeasure(x, beta0))
  opt_quant[b, ]   <- out[[b]]$opt
}

beta_matrix <- matrix(NA, nrow = 6, ncol = 5)
tmp <- NULL
for(i in 1:5) {
  tmp1 <- matrix(NA, nrow = B, ncol = 6)
  for(b in 1:B) {
    tmp1[b, ] <- beta_res[[b]][i, ]
  }
  beta_matrix[, i] <- apply(tmp1, 2,  mean)
  tmp <- c(tmp, c(tmp1))
}
beta_matrix
 
res <- data.frame(beta = c(beta_matrix),
                  method = rep(rep(c("LASSO","nLASSO", "asymLASSO"), each = 2), times = 5),
                  cov = rep(1:5, each = 6),
                  sign = rep(rep(c("Positive", "Negative"), times = 3), times = 5),
                  group = 1:6) %>%
  mutate(sd = sqrt(beta * (1 - beta) / 100))

                  
res$cov = factor(res$cov, labels = c("beta[1]",
                                        "beta[4]",
                                        "beta[6]",
                                        "beta[7]",
                                        "beta[10]"))

res$sign = factor(res$sign, labels = c("beta[j] >= 0",
                                      "beta[j] <= 0"))

res$group = factor(res$group)

group_name <- c(expression(LASSO(italic(X))),
  expression(LASSO(widetilde(italic(X)))),
  expression(nLASSO(italic(X))),
  expression(nLASSO(widetilde(italic(X)))),
  expression(asymLASSO(italic(X))),
  expression(asymLASSO(widetilde(italic(X)))))

ggplot(res %>% filter(cov %in% c("beta[1]", "beta[4]")), 
       aes(y = beta, x = group)) +
  geom_boxplot(aes(lower = beta - sd,
                   upper = beta + sd,
                   middle = beta,
                   ymin = beta - 3 * sd,
                   ymax = beta + 3 * sd),
                   stat = "identity") +
  scale_y_continuous(name = expression(P[j])) +
  coord_cartesian(ylim = c(0, 1)) + 
  scale_x_discrete(name = "",
                   labels = group_name) + 
  facet_wrap(cov ~. , ncol = 1, labeller = label_parsed) +
  theme_classic() +
  theme(legend.position = "top",
        axis.text.x = element_text(size = 11, color = "black"),
        axis.text.y = element_text(size = 11, color = "black"),
        legend.text = element_text(size = 12),
        strip.text = element_text(size = 12))
