rm(list = ls())
library(xrnet)
library(readxl)
library(glmnet)
library(ggplot2)
library(dplyr)
library(xtable)

simSheet <- read_xlsx("simulationList.xlsx", sheet = 4)

# Make sure to comment and un-comment the correct model you are interested in.
# _ind: Main text
# _ar and _cs: Supplemental Table S1 and S2, respectively
# idx = 1: sigma = 0.5
# idx = 3; sigma = 0.3

idx <- 1
load(file = paste0("results/results_s1_tau_ar_", idx, ".RData")) # Main text
#load(file = paste0("results/results_s1_tau_cs_", idx, ".RData")) # Supplemental
#load(file = paste0("results/results_s1_tau_ind_", idx, ".RData")) # Supplemental

beta0
B <- length(out)

source(paste0("sourceFiles/evaluationMeasures.R"))

# Store results in these matrices
bias_matrix <- matrix(NA, nrow = B, ncol = 20)
mse_matrix  <- matrix(NA, nrow = B, ncol = 20)
r2_matrix   <- matrix(NA, nrow = B, ncol = 20)
fp_matrix   <- matrix(NA, nrow = B, ncol = 20)
fn_matrix   <- matrix(NA, nrow = B, ncol = 20)
sm_matrix   <- matrix(NA, nrow = B, ncol = 20)
beta_res    <- list()
opt_quant   <- matrix(NA, nrow = B, ncol = 1)
mean_y      <- numeric()
#- Get simulation results
for(b in 1:B) {
  bias_matrix[b, ] <- apply(out[[b]]$betas, 1, function(x) sum((x - b0)^2))
  beta_res[[b]]    <- apply(out[[b]]$betas, 1, function(x) getBetaCounts(x, b0))
  fn_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, b0))[1, ]
  fp_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, b0))[2, ]
  sm_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getSimilarityMeasure(x, b0))
  mse_matrix[b, ]  <- out[[b]]$mse / out[[b]]$mse[1]
  opt_quant[b, ]   <- out[[b]]$opt 
}

beta_matrix <- matrix(NA, nrow = 20, ncol = 6)
for(i in 1:6) {
  tmp <- matrix(NA, nrow = B, ncol = 20)
  for(b in 1:B) {
    tmp[b, ] <- beta_res[[b]][i, ]
  }
  beta_matrix[, i] <- apply(tmp, 2,  mean)
}
rm(i, b)


#####- Output results
res_table <- cbind(beta_matrix)
res_table <- res_table[c(1, 2, 6, 12, 17, 20), ]; 
colnames(res_table) <- c(paste0("beta_", which(b0!=0)))
rownames(res_table) <- c("CV", "0.05", "0.25", "0.5",  "0.75", "0.95")

xtable(res_table)
apply(opt_quant, 2, mean)
