#- Simulation 1: Comparison of tau

rm(list = ls())
library(xrnet)
library(readxl)
library(glmnet)
library(doParallel)

#- Source important files
source("sourceFiles/sourceFiles.R")
source("sourceFiles/getLossFunctions.R")
simSheet <- read_xlsx("simulationList.xlsx", sheet = 4)
simSheet
B <- 100

tau.seq <- seq(0.05, 0.95, by = 0.05)
nCores  <- 6 

#sim = 1 and 3 are shown in Table S1
for(sim in c(1, 3)) {
  #- Simulation parameters
  simParams <- simSheet[sim, ]
  n.train   <- simParams$nobs
  b0        <- c(-0.03, 0, 0, -0.03, -0.03, 0.03, 0.03, 0, 0, 0.03)
  
  n.sim <- n.train + 1000
  V     <- createCorrelationStructure(p = 10, method = "ar", rho = 0.50)
  cV     <- chol(V)
  out <- list() # Results from simulation
  set.seed(simParams$seed)
  for(b in 1:B) {
    cat(paste0("Simulation: ", b, "\r"))
    #- Simulate data
    Z   <- matrix(rnorm(n.sim * 10), nrow = n.sim)
    Z   <- Z %*% cV # Create correlation structure
    
    intcpt <- 0.10
    y      <- rnorm(n.sim, mean = intcpt + Z %*% b0,
                    sd = simParams$sigma)   

    #- Split training and test set    
    y.train <- y[1:n.train]
    Z.train <- Z[1:n.train, ]
    y.test  <- y[-(1:n.train)]
    Z.test  <- Z[-(1:n.train), ]
    
    #- Create Fold ID for Cross Validation
    foldId <- sample(1:5, size = length(y.train), replace = TRUE)
    
    
    #- Fit asymmetric LASSO regularization 
    quantile_beta <- matrix(NA, nrow = length(tau.seq), ncol = 10)
    rownames(quantile_beta) <- paste("tau = ", tau.seq)
    
    quantile_cvm  <- numeric()
    quantile_mse  <- numeric()
    quantile_r2   <- numeric()
    
    for(j in 1:length(tau.seq)) {
      registerDoParallel(nCores)
      fit.quantile       <- tune_xrnet(Z.train, y.train, family = "gaussian",
                                       penalty_main = define_penalty("q1", tau.seq[j], 
                                                                     num_penalty = 20),
                                       loss = "deviance",
                                       nfolds = 5,
                                       foldid = foldId,
                                       parallel = TRUE)
      stopImplicitCluster()
      
      quantile_beta[j, ] <- coef(fit.quantile)$betas[, , 1]
      quantile_cvm[j]    <- min(fit.quantile$cv_mean)
      pred.quantile      <- predict(fit.quantile, newdata = Z.test,
                                    p = "opt")
      quantile_mse[j]    <- mean((y.test - pred.quantile)^2)
    }

    #- Concatenate results:
    results_from_simulation <- list()
    results_from_simulation$betas <- rbind(quantile_beta[which.min(quantile_cvm), ],
                                           quantile_beta)
    results_from_simulation$opt   <- c(tau.seq[which.min(quantile_cvm)])
    results_from_simulation$mse   <- c(quantile_mse[which.min(quantile_cvm)],
                                      quantile_mse)
    out[[b]] <- results_from_simulation
  } # End simulation
  # Save simulation results
  save(simParams, out, b0, file = paste0("results/results_s1_tau_ar_", sim, ".RData"))
}


