rm(list = ls())
library(xrnet)
library(readxl)
library(glmnet)
library(ggplot2)
library(dplyr)
library(gridExtra)
library(xtable)

#- Source important files
simSheet <- read_xlsx("simulationList.xlsx", sheet = 1)
idx <- 1
load(file = paste0("results/results_s2_2_", idx, ".RData"))

B <- length(out)

source("sourceFiles/evaluationMeasures.R")

# Store results in these matrices
bias_matrix <- matrix(NA, nrow = B, ncol = 26)
mse_matrix  <- matrix(NA, nrow = B, ncol = 26)
r2_matrix   <- matrix(NA, nrow = B, ncol = 26)
fp_matrix   <- matrix(NA, nrow = B, ncol = 26)
fn_matrix   <- matrix(NA, nrow = B, ncol = 26)
sm_matrix   <- matrix(NA, nrow = B, ncol = 26)
ms_matrix   <- matrix(NA, nrow = B, ncol = 26)
beta_res    <- list()
opt_quant   <- matrix(NA, nrow = B, ncol = 3)
#- Get simulation results
for(b in 1:B) {
  bias_matrix[b, ] <- apply(out[[b]]$betas, 1, function(x) sqrt(sum((x - beta0)^2)))
  beta_res[[b]]    <- apply(out[[b]]$betas, 1, function(x) getBetaCounts(x, beta0))
  fn_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, beta0))[1, ]
  fp_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelection(x, beta0))[2, ]
  sm_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getSimilarityMeasure(x, beta0))
  #ms_matrix[b, ]   <- apply(out[[b]]$betas, 1, function(x) getModelSelectionMeasure(x, beta0))
  #mse_matrix[b, ]  <- (out[[b]]$mse[1] - out[[b]]$mse) / out[[b]]$mse[1] 
  mse_matrix[b, ]  <- out[[b]]$mse
  opt_quant[b, ]   <- out[[b]]$opt
}

sm_matrix <- ifelse(is.nan(sm_matrix), 0, sm_matrix) #- Convert NaN to 0

beta_matrix <- matrix(NA, nrow = 26, ncol = 5)
for(i in 1:5) {
  tmp <- matrix(NA, nrow = B, ncol = 26)
  for(b in 1:B) {
    tmp[b, ] <- beta_res[[b]][i, ]
  }
  beta_matrix[, i] <- apply(tmp, 2,  mean)
}
rm(i, b)


#####- Output results
#- Tables
apply(opt_quant, 2, mean)

res_table <- cbind(apply(bias_matrix, 2, mean),
                   apply(fp_matrix, 2, mean),
                   beta_matrix,
                   #apply(fn_matrix, 2, mean),
                   apply(sm_matrix, 2, function(x) mean(x, na.rm = TRUE)),
                   apply(mse_matrix, 2, mean))

# 1) Oracle, 2) Adaptive Lasso, 3) SCAD, 4) MCP, 24-26) Opt Q1 
#res_table <- res_table[c(1:4, 24:26, 9, 14, 19), ]
res_table <- res_table[c(2, 24, 9, 19), ]
colnames(res_table) <- c("MSB", "FP", paste0("beta_", which(beta0!=0)), "SM", "MSE")
#rownames(res_table) <- c("ORACLE", "ALASSO", "SCAD", "MCP", "Q1(opt)", "Q1(low)", "Q1(high)", "Q1(0.25)", "Q1(0.5)", "Q1(0.75)")
rownames(res_table) <- c("ALASSO", "Q1(opt)", "Q1(0.25)", "Q1(0.75)")
xtable(res_table)
apply(opt_quant, 2, mean)
simSheet[idx, ]

