# Evaluation Measures for Simulations
getModelSelection <- function(x, beta0) {
  
  nzero.idx  <- which(beta0 != 0)
  zero.idx  <- which(beta0 == 0)
  false.neg <- sum(x[nzero.idx] == 0) #False Negative (which non zeros are classified as zeros)
  #true.pos  <- sum(bhat[-zero.idx] != 0)  #True Positive (which non zeros are actually non zero)
  false.pos <- sum(x[zero.idx] != 0) #False Positive (which zeros are classified as non zero)
  true.pos  <- sum(x[nzero.idx] != 0)  #True Positive (which non zeros are actually non zero)
  #out <- c(true.pos, true.neg, false.pos, false.neg)
  #names(out) <- c("TP", "TN", "FP", "TN")
  out <- c(false.neg, false.pos, true.pos)
  names(out) <- c("FN", "FP", "TP")
  return(out)
}

# Evaluation Measures for Simulations
getBetaCounts <- function(x, beta0) {
  zero.idx  <- which(beta0 == 0)
  true.pos  <- x[-zero.idx] != 0 #False Negative (which non zeros are classified as zeros)
  #true.pos  <- sum(bhat[-zero.idx] != 0)  #True Positive (which non zeros are actually non zero)
  false.pos <- sum(x[zero.idx] != 0) #False Positive (which zeros are classified as non zero)
  #out <- c(true.pos, true.neg, false.pos, false.neg)
  #names(out) <- c("TP", "TN", "FP", "TN")
  out <- true.pos
  names(out) <- paste0("beta_", which(beta0!= 0))
  return(out)
}

getSimilarityMeasure <- function(bhat, b0) {
  bhat.idx <- which(bhat != 0)
  b0.idx <- which(b0 != 0)
  return(length(intersect(bhat.idx, b0.idx)) / sqrt(length(bhat.idx) * length(b0.idx)))
}

getModelSelectionMeasure <- function(bhat, b0) {
  #- Identify true covariates
  nzero.idx <- which(b0 != 0)
  zero.idx  <- which(b0 == 0)
  out <- (sum(which(bhat == 0) %in% zero.idx) + sum(which(bhat != 0) %in% nzero.idx)) == length(bhat)
  return(out)
}
