# Simulate Linear Regression Data
simluateLinearModelData <- function(n.sim, n.cov, beta0, Z, eps.sd = 1, intcpt = 0.5) {
  beta0 <- c(intcpt, beta0)
  Z     <- cbind(1, Z)
  y     <- Z %*% beta0 + rnorm(n.sim, sd = eps.sd)
  return(list(Z = Z[, -1],
               y = y))
}

# Simulate Correlation Structure
createCorrelationStructure <- function(p, method = "cs", rho = 0.5) {
  #- Create Correlation Structure:
  if(method == "cs") {
    # Compound symmetry
    V <- matrix(rho, nrow = p, ncol = p)
    diag(V) <- 1
  } else if (method == "ar") {
    # Autoregressive
    V <- matrix(0, ncol = p, nrow = p)
    for(index in 1:p){
      V[index, ] <-
        c(rev(cumprod(rep(rho, index - 1))), 
          1, 
          cumprod(rep(rho, p - index)))
    }; rm(index)
  } else if (method == "ind") {
    # Independence
    V <- diag(p)
  }
  return(V)
}
